@@ -412,13 +412,13 @@ def auto_corr_scat_factor(lags, beta, relaxation_rate, baseline=1):
     scattering factor(ISF) g1
 
     .. math::
-        g_2(q, \\tau) = \\beta_1[g_1(q, \\tau)]^{2} + g_\infty
+        g_2(q, \\tau) = \\beta_1[g_1(q, \\tau)]^{2} + g_\\infty
 
     For a system undergoing  diffusive dynamics,
     .. math::
-        g_1(q, \\tau) = e^{-\gamma(q) \\tau}
+        g_1(q, \\tau) = e^{-\\gamma(q) \\tau}
     .. math::
-       g_2(q, \\tau) = \\beta_1 e^{-2\gamma(q) \\tau} + g_\infty
+       g_2(q, \\tau) = \\beta_1 e^{-2\\gamma(q) \\tau} + g_\\infty
 
     These implementation are based on published work. [1]_
 
@@ -1016,9 +1016,11 @@ class CrossCorrelator:
             maskcorr = _cross_corr(submask)
             # choose some small value to threshold
             maskcorr *= maskcorr > .5
+            # This following line was originally placed two lines below. It was moved here in order
+            #   to avoid runtime warnings during the execution of '>' (zeros are replaced by 'nan' values)
+            self.pxlst_maskcorrs.append(maskcorr > 0)
             maskcorr[np.where(maskcorr == 0)] = np.nan
             self.maskcorrs.append(maskcorr)
-            self.pxlst_maskcorrs.append(maskcorr > 0)
             # centers are shape//2 as performed by fftshift
             center = np.array(maskcorr.shape)//2
             self.centers.append(np.array(maskcorr.shape)//2)
@@ -1167,6 +1169,6 @@ def _cross_corr(img1, img2=None):
     # fftconvolve(A,B) = FFT^(-1)(FFT(A)*FFT(B))
     # but need FFT^(-1)(FFT(A(x))*conj(FFT(B(x)))) = FFT^(-1)(A(x)*B(-x))
     reverse_index = [slice(None, None, -1) for i in range(ndim)]
-    imgc = fftconvolve(img1, img2[reverse_index], mode='full')
+    imgc = fftconvolve(img1, img2[tuple(reverse_index)], mode='full')
 
     return imgc
